zero-one.geni.catalog


cache-tablecljmultimethod

source

cached?cljmultimethod

source

catalogclj

(catalog)
(catalog spark)
source

clear-cachecljmultimethod

source

current-catalogcljmultimethod

Returns the name of the session's current catalog, such as "spark_catalog", Spark's built-in one.

Returns the name of the session's current catalog, such as
`"spark_catalog"`, Spark's built-in one.
sourceraw docstring

current-databasecljmultimethod

source

database-exists?cljmultimethod

source

drop-global-temp-viewcljmultimethod

source

drop-relationcljmultimethod

source

drop-tablecljmultimethod

source

drop-temp-viewcljmultimethod

source

drop-viewcljmultimethod

source

list-catalogscljmultimethod

Returns a Dataset of the session's catalogs, with a name and a description column, or only those whose names match the pattern, where * matches any characters.

Returns a Dataset of the session's catalogs, with a `name` and a
`description` column, or only those whose names match the pattern, where
`*` matches any characters.
sourceraw docstring

list-columnscljmultimethod

source

list-databasescljmultimethod

source

list-tablescljmultimethod

source

recover-partitionscljmultimethod

source

refresh-by-pathcljmultimethod

source

refresh-tablecljmultimethod

source

set-current-catalogcljmultimethod

Makes the catalog catalog-name the session's current one, for the table names that don't name a catalog. A catalog other than Spark's built-in one comes from a spark.sql.catalog.<name> config.

Makes the catalog `catalog-name` the session's current one, for the table
names that don't name a catalog. A catalog other than Spark's built-in one
comes from a `spark.sql.catalog.<name>` config.
sourceraw docstring

set-current-databasecljmultimethod

source

table-exists?cljmultimethod

source

table-identifierclj

(table-identifier database name)
source

uncache-tablecljmultimethod

source

cljdoc builds & hosts documentation for Clojure/Script libraries