Column: Gives the column an alias.
Dataset: Returns a new Dataset with an alias set.
Column: Gives the column an alias. Dataset: Returns a new Dataset with an alias set.
Column: Gives the column an alias.
Dataset: Returns a new Dataset with an alias set.
Column: Gives the column an alias. Dataset: Returns a new Dataset with an alias set.
Column: variadic version of map-concat.
Dataset: variadic version of with-column.
Column: variadic version of `map-concat`. Dataset: variadic version of `with-column`.
Column: Aggregate function: returns the average of the values in a group.
RelationalGroupedDataset: Compute the average value for each numeric columns for each group.
Column: Aggregate function: returns the average of the values in a group. RelationalGroupedDataset: Compute the average value for each numeric columns for each group.
Column: Returns the first column that is not null, or null if all inputs are null.
Dataset: Returns a new Dataset that has exactly numPartitions partitions, when the fewer partitions are requested.
Column: Returns the first column that is not null, or null if all inputs are null. Dataset: Returns a new Dataset that has exactly numPartitions partitions, when the fewer partitions are requested.
Column: Aggregate function: returns the Pearson Correlation Coefficient for two columns.
Datasate: Calculates the Pearson Correlation Coefficient of two columns of a DataFrame.
Column: Aggregate function: returns the Pearson Correlation Coefficient for two columns. Datasate: Calculates the Pearson Correlation Coefficient of two columns of a DataFrame.
Column: Aggregate function: returns the number of items in a group.
Dataset: Returns the number of rows in the Dataset.
RelationalGroupedDataset: Count the number of rows for each group.
Column: Aggregate function: returns the number of items in a group. Dataset: Returns the number of rows in the Dataset. RelationalGroupedDataset: Count the number of rows for each group.
Column: Returns a map whose key is not in ks.
Dataset: variadic version of drop.
Column: Returns a map whose key is not in `ks`. Dataset: variadic version of `drop`.
Column: Prints the expression to the console for debugging purposes.
Dataset: Prints the plan to the console for debugging purposes. mode is
one of :simple, the default, which prints the physical plan, :extended,
which adds the logical plans, :codegen, :cost and :formatted. true
stands for :extended, and false for :simple. explain-string returns
the plan instead.
Column: Prints the expression to the console for debugging purposes. Dataset: Prints the plan to the console for debugging purposes. `mode` is one of `:simple`, the default, which prints the physical plan, `:extended`, which adds the logical plans, `:codegen`, `:cost` and `:formatted`. `true` stands for `:extended`, and `false` for `:simple`. `explain-string` returns the plan instead.
Column: Returns an array of elements for which a predicate holds in a given array.
Dataset: Filters rows using the given condition.
Column: Returns an array of elements for which a predicate holds in a given array. Dataset: Filters rows using the given condition.
Column: Aggregate function: returns the first value of a column in a group.
Dataset: Returns the first row.
Column: Aggregate function: returns the first value of a column in a group. Dataset: Returns the first row.
Column: Aggregate function: returns the inter-quartile range of the values in a group.
RelationalGroupedDataset: Compute the inter-quartile range for each numeric columns for each group.
Column: Aggregate function: returns the inter-quartile range of the values in a group. RelationalGroupedDataset: Compute the inter-quartile range for each numeric columns for each group.
Column: Aggregate function: returns the inter-quartile range of the values in a group.
RelationalGroupedDataset: Compute the inter-quartile range for each numeric columns for each group.
Column: Aggregate function: returns the inter-quartile range of the values in a group. RelationalGroupedDataset: Compute the inter-quartile range for each numeric columns for each group.
Column: Aggregate function: returns the last value of the column in a group.
Dataset: Returns the last row.
Column: Aggregate function: returns the last value of the column in a group. Dataset: Returns the last row.
Column: Aggregate function: returns the maximum value of the column in a group.
RelationalGroupedDataset: Compute the max value for each numeric columns for each group.
Column: Aggregate function: returns the maximum value of the column in a group. RelationalGroupedDataset: Compute the max value for each numeric columns for each group.
Column: Aggregate function: returns the average of the values in a group.
RelationalGroupedDataset: Compute the average value for each numeric columns for each group.
Column: Aggregate function: returns the average of the values in a group. RelationalGroupedDataset: Compute the average value for each numeric columns for each group.
Column: Aggregate function: returns the exact median of the values in a
group, as Spark's median does. g/percentile-approx gives an approximate
one, with less memory.
RelationalGroupedDataset: Compute the median for each numeric columns for each group.
Column: Aggregate function: returns the exact median of the values in a group, as Spark's `median` does. `g/percentile-approx` gives an approximate one, with less memory. RelationalGroupedDataset: Compute the median for each numeric columns for each group.
Column: Aggregate function: returns the minimum value of the column in a group.
RelationalGroupedDataset: Compute the min value for each numeric columns for each group.
Column: Aggregate function: returns the minimum value of the column in a group. RelationalGroupedDataset: Compute the min value for each numeric columns for each group.
Column: Aggregate function: returns the quantile of the values in a group.
RelationalGroupedDataset: Compute the quantile for each numeric columns for each group.
Column: Aggregate function: returns the quantile of the values in a group. RelationalGroupedDataset: Compute the quantile for each numeric columns for each group.
Column: Returns a random permutation of the given array.
Dataset: Shuffles the rows of the Dataset.
Column: Returns a random permutation of the given array. Dataset: Shuffles the rows of the Dataset.
Column: Aggregate function: returns the sum of all values in the given column.
RelationalGroupedDataset: Compute the sum for each numeric columns for each group.
Column: Aggregate function: returns the sum of all values in the given column. RelationalGroupedDataset: Compute the sum for each numeric columns for each group.
Collection: alias for table->dataset.
Dataset: Converts this strongly typed collection of data to generic DataFrame with columns renamed.
Collection: alias for `table->dataset`. Dataset: Converts this strongly typed collection of data to generic DataFrame with columns renamed.
Column: Converts a column containing a StructType, ArrayType or a MapType into a JSON string with the specified schema.
Dataset: Returns the content of the Dataset as a Dataset of JSON strings.
Column: Converts a column containing a StructType, ArrayType or a MapType into a JSON string with the specified schema. Dataset: Returns the content of the Dataset as a Dataset of JSON strings.
Column: transform-values with Clojure's assoc signature.
Dataset: with-column with Clojure's assoc signature.
Column: `transform-values` with Clojure's `assoc` signature. Dataset: `with-column` with Clojure's `assoc` signature.
Column: transform-values with Clojure's assoc signature.
Dataset: with-column with Clojure's assoc signature.
Column: `transform-values` with Clojure's `assoc` signature. Dataset: `with-column` with Clojure's `assoc` signature.
Column: Returns an array of elements for which a predicate holds in a given array.
Dataset: Filters rows using the given condition.
Column: Returns an array of elements for which a predicate holds in a given array. Dataset: Filters rows using the given condition.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |