zero-one.geni.rdd.function


access-fieldclj

(access-field field obj)
source

flat-map-functionclj

(flat-map-function f)

Construct a new serializable FlatMapFn1 function wrapping f.

Construct a new serializable FlatMapFn1 function wrapping `f`.
sourceraw docstring

flat-map-function2clj

(flat-map-function2 f)

Construct a new serializable FlatMapFn2 function wrapping f.

Construct a new serializable FlatMapFn2 function wrapping `f`.
sourceraw docstring

functionclj

(function f)

Construct a new serializable Fn1 function wrapping f.

Construct a new serializable Fn1 function wrapping `f`.
sourceraw docstring

function2clj

(function2 f)

Construct a new serializable Fn2 function wrapping f.

Construct a new serializable Fn2 function wrapping `f`.
sourceraw docstring

namespace-referencesclj

(namespace-references obj)

The namespaces that the executors need to load to run obj, a function: the one that defines it, and those of the vars and functions that it uses or closes over, except clojure.core.

The namespaces that the executors need to load to run `obj`, a function:
the one that defines it, and those of the vars and functions that it uses
or closes over, except clojure.core.
sourceraw docstring

pair-flat-map-functionclj

(pair-flat-map-function f)

Construct a new serializable PairFlatMapFn function wrapping f.

Construct a new serializable PairFlatMapFn function wrapping `f`.
sourceraw docstring

pair-functionclj

(pair-function f)

Construct a new serializable PairFn function wrapping f.

Construct a new serializable PairFn function wrapping `f`.
sourceraw docstring

void-functionclj

(void-function f)

Construct a new serializable VoidFn function wrapping f.

Construct a new serializable VoidFn function wrapping `f`.
sourceraw docstring

walk-object-varsclj

(walk-object-vars references visited obj)

Adds to references the namespaces of the vars, and of the functions, that obj holds, as its fields or as the elements of a collection, however deeply. visited keeps it from walking an object twice.

Adds to `references` the namespaces of the vars, and of the functions, that
`obj` holds, as its fields or as the elements of a collection, however
deeply. `visited` keeps it from walking an object twice.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries