The SparkSession that Geni functions use when they aren't given one. Requiring Geni doesn't start Spark: the session is looked up, or created, when a function first needs it.
The SparkSession that Geni functions use when they aren't given one. Requiring Geni doesn't start Spark: the session is looked up, or created, when a function first needs it.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |