Returns the name of the session's current catalog, such as
"spark_catalog", Spark's built-in one.
Returns the name of the session's current catalog, such as `"spark_catalog"`, Spark's built-in one.
Returns a Dataset of the session's catalogs, with a name and a
description column, or only those whose names match the pattern, where
* matches any characters.
Returns a Dataset of the session's catalogs, with a `name` and a `description` column, or only those whose names match the pattern, where `*` matches any characters.
Makes the catalog catalog-name the session's current one, for the table
names that don't name a catalog. A catalog other than Spark's built-in one
comes from a spark.sql.catalog.<name> config.
Makes the catalog `catalog-name` the session's current one, for the table names that don't name a catalog. A catalog other than Spark's built-in one comes from a `spark.sql.catalog.<name>` config.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |