(avg-metrics model)A cross-validator model's metric for each of its estimator's param maps,
averaged over the folds, in the order of :estimator-param-maps.
A cross-validator model's metric for each of its estimator's param maps, averaged over the folds, in the order of `:estimator-param-maps`.
(cross-validator {:keys [estimator evaluator estimator-param-maps num-folds seed
parallelism collect-sub-models]})K-fold cross validation performs model selection by splitting the dataset into a set of non-overlapping randomly partitioned folds which are used as separate training and test datasets e.g., with k=3 folds, K-fold cross validation will generate 3 (training, test) dataset pairs, each of which uses 2/3 of the data for training and 1/3 for testing. Each fold is used as the test set exactly once.
Source: https://spark.apache.org/docs/3.0.1/api/scala/org/apache/spark/ml/tuning/CrossValidator.html
Timestamp: 2020-10-19T01:55:48.855Z
K-fold cross validation performs model selection by splitting the dataset into a set of non-overlapping randomly partitioned folds which are used as separate training and test datasets e.g., with k=3 folds, K-fold cross validation will generate 3 (training, test) dataset pairs, each of which uses 2/3 of the data for training and 1/3 for testing. Each fold is used as the test set exactly once. Source: https://spark.apache.org/docs/3.0.1/api/scala/org/apache/spark/ml/tuning/CrossValidator.html Timestamp: 2020-10-19T01:55:48.855Z
(param-grid grids)Builder for a param grid used in grid search-based model selection.
Source: https://spark.apache.org/docs/3.0.1/api/scala/org/apache/spark/ml/tuning/ParamGridBuilder.html
Timestamp: 2020-10-19T01:55:49.184Z
Builder for a param grid used in grid search-based model selection. Source: https://spark.apache.org/docs/3.0.1/api/scala/org/apache/spark/ml/tuning/ParamGridBuilder.html Timestamp: 2020-10-19T01:55:49.184Z
(param-grid-builder grids)Builder for a param grid used in grid search-based model selection.
Source: https://spark.apache.org/docs/3.0.1/api/scala/org/apache/spark/ml/tuning/ParamGridBuilder.html
Timestamp: 2020-10-19T01:55:49.184Z
Builder for a param grid used in grid search-based model selection. Source: https://spark.apache.org/docs/3.0.1/api/scala/org/apache/spark/ml/tuning/ParamGridBuilder.html Timestamp: 2020-10-19T01:55:49.184Z
(sub-models model)The models that a cross-validator or a train-validation split fitted for
each param map, with :collect-sub-models true: a vector per fold of a
model per param map for a cross-validator, and a model per param map for a
split. Nil when it didn't keep them.
The models that a cross-validator or a train-validation split fitted for each param map, with `:collect-sub-models true`: a vector per fold of a model per param map for a cross-validator, and a model per param map for a split. Nil when it didn't keep them.
(train-validation-split {:keys [estimator evaluator estimator-param-maps seed
parallelism collect-sub-models train-ratio]})Validation for hyper-parameter tuning. Randomly splits the input dataset into train and validation sets, and uses evaluation metric on the validation set to select the best model. Similar to CrossValidator, but only splits the set once.
Source: https://spark.apache.org/docs/3.0.1/api/scala/org/apache/spark/ml/tuning/TrainValidationSplit.html
Timestamp: 2020-10-19T01:55:49.563Z
Validation for hyper-parameter tuning. Randomly splits the input dataset into train and validation sets, and uses evaluation metric on the validation set to select the best model. Similar to CrossValidator, but only splits the set once. Source: https://spark.apache.org/docs/3.0.1/api/scala/org/apache/spark/ml/tuning/TrainValidationSplit.html Timestamp: 2020-10-19T01:55:49.563Z
(validation-metrics model)A train-validation split model's metric for each of its estimator's param
maps, in the order of :estimator-param-maps.
A train-validation split model's metric for each of its estimator's param maps, in the order of `:estimator-param-maps`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |