(flat-map-function f)Construct a new serializable FlatMapFn1 function wrapping f.
Construct a new serializable FlatMapFn1 function wrapping `f`.
(flat-map-function2 f)Construct a new serializable FlatMapFn2 function wrapping f.
Construct a new serializable FlatMapFn2 function wrapping `f`.
(function f)Construct a new serializable Fn1 function wrapping f.
Construct a new serializable Fn1 function wrapping `f`.
(function2 f)Construct a new serializable Fn2 function wrapping f.
Construct a new serializable Fn2 function wrapping `f`.
(namespace-references obj)The namespaces that the executors need to load to run obj, a function:
the one that defines it, and those of the vars and functions that it uses
or closes over, except clojure.core.
The namespaces that the executors need to load to run `obj`, a function: the one that defines it, and those of the vars and functions that it uses or closes over, except clojure.core.
(pair-flat-map-function f)Construct a new serializable PairFlatMapFn function wrapping f.
Construct a new serializable PairFlatMapFn function wrapping `f`.
(pair-function f)Construct a new serializable PairFn function wrapping f.
Construct a new serializable PairFn function wrapping `f`.
(void-function f)Construct a new serializable VoidFn function wrapping f.
Construct a new serializable VoidFn function wrapping `f`.
(walk-object-vars references visited obj)Adds to references the namespaces of the vars, and of the functions, that
obj holds, as its fields or as the elements of a collection, however
deeply. visited keeps it from walking an object twice.
Adds to `references` the namespaces of the vars, and of the functions, that `obj` holds, as its fields or as the elements of a collection, however deeply. `visited` keeps it from walking an object twice.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |